pub enum Error {
IoError(Error),
KeyValueParseError(String),
UnknownStatusError(String),
OtherParseError(Box<dyn Error + Send>, String),
}Expand description
Various errors that can occur as it runs.
Variants
IoError(Error)
Anything threw an io::Error.
KeyValueParseError(String)
Ffmpeg gave us data that wasn’t actually a key=value pair.
Hasn’t happened in my testing, but I wouldn’t put it past ffmpeg.
UnknownStatusError(String)
Ffmpeg put out something unexpected for progress.
OtherParseError(Box<dyn Error + Send>, String)
Any other error that can occur while parsing ffmpeg output.
Can only be a float or int parsing error. The String is what it was trying to parse.